Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
opentelemetry.core, opentelemetry, opentelemetry.util, opentelemetry.emitter, opentelemetry.atomic, revamp internalsopentelemetry.ambient-context is now a standalone library, once againopentelemetry-client-ocurl-lwt packageopentelemetry-client-sync off of the main client libraryhttp/json protocol alongside http/protobufExporter_add_batching, Emitter_add_batching, Emitter_sample, Emitter_limit_interval combinators. Batching is factored out of individual client libraries.exporter_stdout and debug_exporterself_metrics and self_debug to exportersafter_shutdown callback in ocurl/ocurl-lwt clientsSpan.dummy: inert span that is never modifiedSpan.record_exception now also sets the span status to errorSpan.set_span_status added in opentelemetry.traceSpan: carry flags to span_linkSpan: now mutable thanks to ocaml-protoc 4.0, replaces old Scope.t entirelyMeter.emit and Meter_provider.emit_l addedflat_map, tap, to_list, enabled combinatorsptime used by default in logger and metricsmetrics_callbacksCollector.cleanup so it takes a callbackGlobals.service_versionpp implemtation for Client_ocurl.ConfigTraceparent.to_valueSpan_kind.t, add {kind,set_kind} to ScopeSpan_status typesScope.set_span_statusrecord_exceptionexception.messagetick() before cleaning upScope.t (@tatchi)hmap, add standard keys to carry around a span context or trace idThread_local with ocaml-ambient-context, allowing for implicit scope in Lwt/Eio contexts (#34)ocaml-trace interface to use the new trace.0.3-style API (breaking, see #34)try%lwt over Lwt.catchopentelemetry.trace (optional, depends on ocaml-trace)Scope.get_surroundingTrace.with_ now has force_new_trace_id paramSpan_link moduleGlobals.default_span_kind ref to specify default span kindtick version used in the absence of bg threadConfig.t private (breaking)Metrics_callbacks moduletick function (useful in the absence of a background thread)OTEL_OCAML_DEBUG