package opentelemetry-lwt

  1. Overview
  2. Docs

Module Opentelemetry_lwt.MetricsSource

include module type of struct include Opentelemetry.Metrics end

A single metric, measuring some time-varying quantity or statistical distribution. It is composed of one or more data points that have precise values and time stamps. Each distinct metric should have a distinct name.

Sourceval float : ?start_time_unix_nano:??? -> ?attrs:??? -> ?now:??? -> float -> Opentelemetry_core.Common_.Proto.Metrics.number_data_point

Number data point, as a float

Sourceval int : ?start_time_unix_nano:??? -> ?attrs:??? -> ?now:??? -> int -> Opentelemetry_core.Common_.Proto.Metrics.number_data_point

Number data point, as an int

Sourceval gauge : name:string -> ?description:??? -> ?unit_:??? -> Opentelemetry_core.Common_.Proto.Metrics.number_data_point list -> t

Aggregation of a scalar metric, always with the current value

Sourcetype aggregation_temporality = Opentelemetry_core.Common_.Proto.Metrics.aggregation_temporality =
  1. | Aggregation_temporality_unspecified
  2. | Aggregation_temporality_delta
  3. | Aggregation_temporality_cumulative
Sourceval sum : name:string -> ?description:??? -> ?unit_:??? -> ?aggregation_temporality:??? -> ?is_monotonic:??? -> Opentelemetry_core.Common_.Proto.Metrics.number_data_point list -> t

Sum of all reported measurements over a time interval

Sourceval histogram_data_point : ?start_time_unix_nano:??? -> ?attrs:??? -> ?exemplars:??? -> explicit_bounds:float list -> ?sum:??? -> ?now:??? -> bucket_counts:int64 list -> count:int64 -> unit -> histogram_data_point

Histogram data

  • parameter count

    number of values in population (non negative)

  • parameter sum

    sum of values in population (0 if count is 0)

  • parameter now

    the timestamp for this data point

  • parameter bucket_counts

    count value of histogram for each bucket. Sum of the counts must be equal to count. length must be 1+length explicit_bounds (unless both have length 0)

  • parameter explicit_bounds

    strictly increasing list of bounds for the buckets

Sourceval histogram : name:string -> ?description:??? -> ?unit_:??? -> ?aggregation_temporality:??? -> histogram_data_point list -> t
Sourceval add_attrs : t -> Opentelemetry_core.Key_value.t list -> unit